Skip to contents

Returns the inbreeding coefficient of each individual, obtained from the diagonal of the pedigree relationship matrix as \(F_i = A_{ii} - 1\).

Usage

inbreeding(x, ...)

# S4 method for class 'BreedingExperiment'
inbreeding(x, ...)

Arguments

x

A BreedingExperiment object.

...

Unused.

Value

A named numeric vector of inbreeding coefficients.

See also

Examples

set.seed(1)
be <- simulateBreeding(n_ind = 12, n_marker = 30)
round(inbreeding(be), 4)
#> ind001 ind002 ind003 ind004 ind005 ind006 ind007 ind008 ind009 ind010 ind011 
#>      0      0      0      0      0      0      0      0      0      0      0 
#> ind012 
#>      0